;; Generated package description from vecdb.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "vecdb" "0.1.0.20250715.213239" "An interface to vector databases for embeddings" '((emacs "29.1") (plz "0.8")) :commit "169b7cb9e84b05d20fd09ef613067cf07c63cc86" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :url "https://github.com/ahyatt/vecdb")
